@@ -1,10 +1,9 @@
 #include <librapid/utils/console_utils.hpp>
 
-namespace librapid
-{
+namespace librapid {
 #if defined(LIBRAPID_OS_WINDOWS)
-	consoleSize getConsoleSize()
-	{
+
+	consoleSize getConsoleSize() {
 		static CONSOLE_SCREEN_BUFFER_INFO csbi;
 		int cols, rows;
 
@@ -14,6 +13,7 @@ namespace librapid
 
 		return {rows, cols};
 	}
+
 #elif defined(LIBRAPID_OS_UNIX)
 	consoleSize getConsoleSize()
 	{
