@@ -4,8 +4,7 @@
 #include <chrono>
 #include <librapid/config.hpp>
 
-namespace librapid
-{
+namespace librapid {
 	/**
 	 * \rst
 	 *
